##  Relations
You can also establish relations between fact sheets from the side pane. You can establish a relation by clicking the '+' Add relation icon. Then choose the fact sheets to connect by searching for it or by scrolling down.
![Only fact sheet data that is actually displayed on the report is shown and editable in the pane.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a0efa7a441014b7569ba6af63f0f4_LowRes.gif)
**Note**
  * Only fact sheets that are actually displayed on the report are shown and editable in the pane.
  * Only direct relations to the currently displayed hierarchy levels of the clusters can be displayed. So if the hierarchy of the clusters in the report's view is expanded to the lowest level (e.g., level 3), all relations are visible and editable. However, if the view is aggregated to higher levels (e.g., level 1), no relations to clusters of the lower levels (e.g., level 2 and 3) are visible.
